"use strict";
// Copyright (c) Mito
// Distributed under the terms of the Modified BSD License.
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const Mito_1 = require("../Mito");
const DefaultModal_1 = __importDefault(require("../DefaultModal"));
const LargeSelects_1 = __importDefault(require("../elements/LargeSelects"));
// import css
require("../../../css/all-modals.css");
require("../../../css/import-modal.css");
const LargeSelect_1 = __importDefault(require("../elements/LargeSelect"));
var ImportEnum;
(function (ImportEnum) {
    ImportEnum["SimpleImport"] = "Simple Import";
    ImportEnum["RawPythonImport"] = "Raw Python Import";
})(ImportEnum = exports.ImportEnum || (exports.ImportEnum = {}));
exports.getDfNameError = (pythonCode, newDfNames, existingDfNames) => {
    for (let i = 0; i < newDfNames.length; i++) {
        // Invalid if it's not in the Python
        if (!pythonCode.includes(newDfNames[i])) {
            return `Error: ${newDfNames[i]} is not a name of a variable in your code.`;
        }
        // Or if it's already the name of a sheet
        if (existingDfNames.indexOf(newDfNames[i]) !== -1) {
            return `Error: ${newDfNames[i]} is already the name of a sheet. Please choose a different name.`;
        }
    }
    return undefined;
};
/*
  A modal that allows a user to import data into the sheet.
*/
const ImportModal = (props) => {
    const [importType, setImportType] = react_1.useState(ImportEnum.SimpleImport);
    // Params for a simple import
    const [fileNames, setFileNames] = react_1.useState([]);
    const [importedFiles, setImportedFiles] = react_1.useState([]);
    const [importedFilesError, setImportedFilesError] = react_1.useState('');
    // Params for a raw Python import
    const [pythonCode, setPythonCode] = react_1.useState('');
    const [dfNamesString, setDfNamesString] = react_1.useState('');
    const [dfNameError, setDfNameError] = react_1.useState('');
    function getDataFiles() {
        return __awaiter(this, void 0, void 0, function* () {
            const dataFiles = yield props.mitoAPI.getDataFiles();
            setFileNames(dataFiles);
        });
    }
    react_1.useEffect(() => {
        // To see an explination, read here: https://medium.com/better-programming/how-to-fetch-data-from-an-api-with-react-hooks-9e7202b8afcd
        // TL;DR: we load the data after the component renders
        void getDataFiles();
    }, []); // empty array is necessary to have this run only once
    const updateImportedFile = (index, newImport) => {
        const newImports = [...importedFiles];
        newImports[index] = newImport;
        setImportedFiles(newImports);
    };
    const addNewFileImport = () => {
        const newImports = [...importedFiles];
        newImports.push(fileNames[0]);
        setImportedFiles(newImports);
    };
    /*
        Completes the import step, casing on which sort of import is occuring
    */
    const clickImport = () => __awaiter(void 0, void 0, void 0, function* () {
        if (importType === ImportEnum.SimpleImport) {
            // Don't let them continue if they didn't import
            if (importedFiles.length === 0) {
                setImportedFilesError('Please upload at least one file before continuing.');
                return;
            }
            yield props.mitoAPI.sendSimpleImportMessage(importedFiles);
            props.setModal({ type: Mito_1.ModalEnum.None });
        }
        else {
            // Short curcit early if the user provides an invalid name
            const dfNames = dfNamesString.split(',').map(dfName => dfName.trim());
            const dfNameError = exports.getDfNameError(pythonCode, dfNames, props.dfNames);
            if (dfNameError !== undefined) {
                return setDfNameError(dfNameError);
            }
            yield props.mitoAPI.sendRawPythonImportMessage(pythonCode, dfNames);
            props.setModal({ type: Mito_1.ModalEnum.None });
        }
    });
    return (react_1.default.createElement(DefaultModal_1.default, { header: `Import Data`, modalType: Mito_1.ModalEnum.Import, viewComponent: react_1.default.createElement(react_1.Fragment, null,
            react_1.default.createElement("div", { className: 'modal-element-label' }, "Import Method"),
            react_1.default.createElement(LargeSelect_1.default, { startingValue: undefined, optionsArray: [ImportEnum.SimpleImport, ImportEnum.RawPythonImport], setValue: (value) => setImportType(value), extraLarge: true }),
            importType === ImportEnum.SimpleImport &&
                react_1.default.createElement("div", null,
                    react_1.default.createElement("div", { className: 'modal-element-label mt-2' }, "Files to Import"),
                    react_1.default.createElement("div", { className: 'import-files-select' },
                        react_1.default.createElement(LargeSelects_1.default, { numSelects: importedFiles.length, startingValue: undefined, optionsArray: fileNames, setValue: updateImportedFile, extraLarge: true })),
                    react_1.default.createElement("div", { className: 'modal-add', onClick: addNewFileImport }, "+ Add File"),
                    importedFilesError !== '' &&
                        react_1.default.createElement("div", { className: 'modal-error' }, importedFilesError)),
            importType === ImportEnum.RawPythonImport &&
                react_1.default.createElement("div", null,
                    react_1.default.createElement("div", { className: 'modal-element-label mt-2' }, "Python Code"),
                    react_1.default.createElement("textarea", { className: 'raw-python-textarea', rows: 5, value: pythonCode, onChange: (e) => { setPythonCode(e.target.value); }, autoFocus: true }),
                    react_1.default.createElement("div", { className: 'modal-element-label mt-2' }, "Dataframe Variable Names to Import (comma seperated)"),
                    react_1.default.createElement("input", { className: "modal-input", type: "text", placeholder: 'df1, df2', value: dfNamesString, onChange: (e) => { setDfNamesString(e.target.value); } }),
                    dfNameError !== '' &&
                        react_1.default.createElement("div", { className: 'modal-error' }, dfNameError))), buttons: react_1.default.createElement(react_1.Fragment, null,
            react_1.default.createElement("div", { className: 'modal-close-button modal-dual-button-left', onClick: () => { props.setModal({ type: Mito_1.ModalEnum.None }); } }, " Close "),
            react_1.default.createElement("div", { className: 'modal-action-button modal-dual-button-right', onClick: clickImport }, " Import ")) }));
};
exports.default = ImportModal;
//# sourceMappingURL=ImportModal.js.map